@@ -2,7 +2,7 @@ import requests
 from ratelimit import limits, sleep_and_retry
 import logging
 from powerml.utils.config import get_config
-
+import backoff
 logger = logging.getLogger(__name__)
 
 
@@ -61,6 +61,9 @@ def run_ai(prompt="Say this is a test",
 
 @sleep_and_retry
 @limits(calls=10, period=1)
+@backoff.on_exception(backoff.expo,
+                      requests.exceptions.RequestException,
+                      max_time=300)
 def powerml_completions(params, key):
     headers = {
         'Content-Type': 'application/json',
